@@ -7,13 +7,9 @@
 
 #include <glibtop/proctime.h>
 #include <glibtop/procstate.h>
-#include <unistd.h>
-
-#include <stddef.h>
-#include <cstring>
 
 #include "util.h"
-#include "procman-app.h"
+#include "application.h"
 
 extern "C" {
 #include "e_date.h"
@@ -361,7 +357,7 @@ procman_debug_real(const char *file, int line, const char *func,
     msg = g_strdup_vprintf(format, args);
     va_end(args);
 
-    g_debug("[%.3f %s:%d %s] %s", get_relative_time(), file, line, func, msg);
+    g_print ("[%.3f %s:%d %s] %s\n", get_relative_time(), file, line, func, msg);
 
     g_free(msg);
 }
@@ -504,7 +500,7 @@ namespace procman
 
         g_value_unset(&value);
 
-        time = 100 * time / ProcmanApp::get()->frequency;
+        time = 100 * time / GsmApplication::get()->frequency;
         char *str = format_duration_for_display(time);
         g_object_set(renderer, "text", str, NULL);
         g_free(str);
@@ -638,7 +634,7 @@ namespace procman
 
     std::string format_network(guint64 rate, guint64 max_rate)
     {
-        char* bytes = procman::format_size(rate, max_rate, ProcmanApp::get()->config.network_in_bits);
+        char* bytes = procman::format_size(rate, max_rate, GsmApplication::get()->config.network_in_bits);
         std::string formatted(bytes);
         g_free(bytes);
         return formatted;
@@ -647,20 +643,19 @@ namespace procman
 
     std::string format_network_rate(guint64 rate, guint64 max_rate)
     {
-        return procman::format_rate(rate, max_rate, ProcmanApp::get()->config.network_in_bits);
+        return procman::format_rate(rate, max_rate, GsmApplication::get()->config.network_in_bits);
     }
 
 }
 
-void
-bind_column_to_gsetting (GSettings *settings, GtkTreeViewColumn *column)
+gchar *
+get_monospace_system_font_name ()
 {
-    char *key;
-    gint column_id = gtk_tree_view_column_get_sort_column_id(column);
-    key = g_strdup_printf ("col-%d-width", column_id);
-    g_settings_bind (settings, key, column, "fixed-width", G_SETTINGS_BIND_DEFAULT);
-    g_free (key);
-    key = g_strdup_printf ("col-%d-visible", column_id);
-    g_settings_bind (settings, key, column, "visible", G_SETTINGS_BIND_DEFAULT);
-    g_free (key);
+    GSettings *desktop_settings = g_settings_new ("org.gnome.desktop.interface");
+    char *font;
+
+    font = g_settings_get_string (desktop_settings, "monospace-font-name");
+    g_object_unref (desktop_settings);
+
+    return font;
 }
